==> localnews-thirdparty-api-2.0.5-sources.jar: com/bxm/localnews/thirdparty/controller/PointMallController.java <==
package com.bxm.localnews.thirdparty.controller;

import java.io.IOException;
import java.util.List;

import javax.servlet.http.HttpServletResponse;

import com.bxm.localnews.common.util.ResultUtil;
import com.bxm.localnews.common.vo.Json;
import com.bxm.localnews.param.DeductPointParam;
import com.bxm.localnews.param.StoreNeceParam;
import com.bxm.localnews.thirdparty.dto.OperateUserPointDTO;
import com.bxm.localnews.thirdparty.dto.PointMallDTO;
import com.bxm.localnews.thirdparty.dto.PointStoreBaseDTO;
import com.bxm.localnews.thirdparty.dto.UserPointDTO;
import com.bxm.localnews.thirdparty.service.PointMallService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Api(tags = "3-08 积分商城相关接口", description = "积分商城相关接口操作")
@RestController
@RequestMapping("api/public/points")
public class PointMallController {

    private PointMallService pointMallService;

    @Autowired
    public PointMallController(PointMallService pointMallService) {
        this.pointMallService = pointMallService;
    }

    @ApiOperation(value = "3-08-1 根据栏位获取商品信息", notes = "type: 1:积分商城；2：商品；3：大转盘")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "用户ID", required = false),
            @ApiImplicitParam(name = "type", value = "商品栏位", allowableValues = "1, 2, 3",
                    paramType = "path", dataType = "String", required = true)
    })
    @GetMapping(value = "/{type}")
    public Json<List<PointMallDTO>> pointsMallByType(@RequestParam(value = "userId", required = false) Long userId,
                                                     @PathVariable(value = "type") String type) {

        return ResultUtil.genSuccessResult(this.pointMallService.getPointsMallByType(userId, type));
    }

    @ApiOperation(value = "3-08-2 根据id获取跳转链接", notes = "id为0时，生成积分商城首页链接，为1时生成大转盘跳转链接")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "用户ID", required = true),
            @ApiImplicitParam(name = "id", value = "商品id", required = true)
    })
    @GetMapping(value = "/{id}/url")
    public Json<String> pointsMallById(@PathVariable(value = "id") Long id,
                                       @RequestParam(value = "userId") Long userId) {
        return ResultUtil.genSuccessResult(this.pointMallService.getPointMallById(id, userId));
    }


    @ApiOperation(value = "3-08-3 用户金币信息", notes = "", hidden = true)
    @RequestMapping(value = "/get/balance", method = RequestMethod.GET)
    public UserPointDTO userBalance(StoreNeceParam storeNeceParam) {
        return this.pointMallService.selectJbBalanceByUserId(storeNeceParam);
    }

    @ApiOperation(value = "3-08-4 扣除用户金币", notes = "", hidden = true)
    @RequestMapping(value = "/deduct/balance", method = RequestMethod.POST)
    public OperateUserPointDTO deductBalance(DeductPointParam deductPointParam) {
        return this.pointMallService.deductUserBalance(deductPointParam);
    }

    @ApiOperation(value = "3-08-5 确认扣除用户金币", notes = "", hidden = true)
    @RequestMapping(value = "/confirm/deduct/balance", method = RequestMethod.POST)
    public PointStoreBaseDTO confirmDeductBalance(DeductPointParam deductPointParam) {
        return this.pointMallService.deductConfirmUserBalance(deductPointParam);
    }

    @ApiOperation(value = "3-08-6 添加用户金币", notes = "", hidden = true)
    @RequestMapping(value = "/balance", method = RequestMethod.POST)
    public OperateUserPointDTO addUserBalance(DeductPointParam deductPointParam) {
        return this.pointMallService.addUserBalance(deductPointParam);
    }

    @ApiOperation(value = "3-08-7 直接跳转到积分商城", notes = "新增接口")
    @RequestMapping(value = "/url", method = RequestMethod.GET)
    public void jumpPointMall(@RequestParam("userId") Long userId, HttpServletResponse response) throws IOException {
        response.sendRedirect(this.pointMallService.getPointMallById(0L, userId));
    }
}

==> localnews-thirdparty-api-3.12.0-sources.jar: com/bxm/localnews/thirdparty/controller/PointMallController.java <==
package com.bxm.localnews.thirdparty.controller;

import com.alibaba.fastjson.JSON;
import com.bxm.localnews.common.util.ResultUtil;
import com.bxm.localnews.common.vo.Json;
import com.bxm.localnews.param.DeductPointParam;
import com.bxm.localnews.param.StoreNeceParam;
import com.bxm.localnews.thirdparty.dto.OperateUserPointDTO;
import com.bxm.localnews.thirdparty.dto.PointMallDTO;
import com.bxm.localnews.thirdparty.dto.PointStoreBaseDTO;
import com.bxm.localnews.thirdparty.dto.UserPointDTO;
import com.bxm.localnews.thirdparty.service.PointMallService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.List;

@Api(tags = "3-08 积分商城相关接口", description = "积分商城相关接口操作")
@RestController
@RequestMapping("api/public/points")
@Slf4j
public class PointMallController {

    private PointMallService pointMallService;

    @Autowired
    public PointMallController(PointMallService pointMallService) {
        this.pointMallService = pointMallService;
    }

    @ApiOperation(value = "3-08-1 根据栏位获取商品信息", notes = "type: 1:积分商城；2：商品；3：大转盘")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "用户ID", required = false),
            @ApiImplicitParam(name = "type", value = "商品栏位", allowableValues = "1, 2, 3",
                    paramType = "path", dataType = "String", required = true)
    })
    @GetMapping(value = "/{type}")
    public Json<List<PointMallDTO>> pointsMallByType(@RequestParam(value = "userId", required = false) Long userId,
                                                     @PathVariable(value = "type") String type) {

        return ResultUtil.genSuccessResult(this.pointMallService.getPointsMallByType(userId, type));
    }

    @ApiOperation(value = "3-08-2 根据id获取跳转链接", notes = "id为0时，生成积分商城首页链接，为1时生成大转盘跳转链接")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "用户ID", required = true),
            @ApiImplicitParam(name = "id", value = "商品id", required = true)
    })
    @GetMapping(value = "/{id}/url")
    public Json<String> pointsMallById(@PathVariable(value = "id") Long id,
                                       @RequestParam(value = "userId") Long userId) {
        return ResultUtil.genSuccessResult(this.pointMallService.getPointMallById(id, userId));
    }


    @ApiOperation(value = "3-08-3 用户金币信息", notes = "", hidden = true)
    @RequestMapping(value = "/get/balance", method = RequestMethod.GET)
    public UserPointDTO userBalance(StoreNeceParam storeNeceParam) {
        log.info("获取用户金币信息：{}", JSON.toJSONString(storeNeceParam));

        return this.pointMallService.selectJbBalanceByUserId(storeNeceParam);
    }

    @ApiOperation(value = "3-08-4 扣除用户金币", notes = "", hidden = true)
    @RequestMapping(value = "/deduct/balance", method = RequestMethod.POST)
    public OperateUserPointDTO deductBalance(DeductPointParam deductPointParam) {
        log.info("扣除用户金币信息：{}", JSON.toJSONString(deductPointParam));

        return this.pointMallService.deductUserBalance(deductPointParam);
    }

    @ApiOperation(value = "3-08-5 确认扣除用户金币", notes = "", hidden = true)
    @RequestMapping(value = "/confirm/deduct/balance", method = RequestMethod.POST)
    public PointStoreBaseDTO confirmDeductBalance(DeductPointParam deductPointParam) {
        log.info("确认扣除用户金币信息：{}", JSON.toJSONString(deductPointParam));

        return this.pointMallService.deductConfirmUserBalance(deductPointParam);
    }

    @ApiOperation(value = "3-08-6 添加用户金币", notes = "", hidden = true)
    @RequestMapping(value = "/balance", method = RequestMethod.POST)
    public OperateUserPointDTO addUserBalance(DeductPointParam deductPointParam) {
        log.info("增加用户金币信息：{}", JSON.toJSONString(deductPointParam));

        return this.pointMallService.addUserBalance(deductPointParam);
    }

    @ApiOperation(value = "3-08-7 直接跳转到积分商城", notes = "新增接口")
    @RequestMapping(value = "/url", method = RequestMethod.GET)
    public void jumpPointMall(@RequestParam("userId") Long userId, HttpServletResponse response) throws IOException {
        response.sendRedirect(this.pointMallService.getPointMallById(0L, userId));
    }

    @ApiOperation(value = "3-08-8 调转到大转盘活动", notes = "新增接口")
    @RequestMapping(value = "/activeUrl", method = RequestMethod.GET)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", value = "用户ID", required = true),
            @ApiImplicitParam(name = "activeId", value = "转盘活动ID", required = true)
    })
    public void jumpPointMall(@RequestParam("userId") Long userId, @RequestParam("activeId") Long activeId, HttpServletResponse response) throws IOException {
        response.sendRedirect(this.pointMallService.redirectToActive(userId, activeId));
    }
}
